RchyOptimyx-package:
Gating Hierarchy Optimization for Flow Cytometry
Description
RchyOptimyx is a computational tool which determines the minimal sets of
markers that can identify a target population within a given purity
standard. This can enable panel redesign using smaller subsets of
markers, with consequent savings on reagents, potential for adaptation to older instruments, or the addition of other markers of interest to the panel design.
Arguments
Details
Package:
RchyOptimyx
Type:
Package
Version:
0.99.1
Date:
2011-10-12
License:
Artistic-2.0
LazyLoad:
yes
See the RchyOptimyx function.
References
D. Eppstein, Finding the k shortest paths, SIAM J. Comput., 1998 - Citeseer.